FieldValidatorFlutter class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
address(String? value, {int lengthLimit = 5})
→ String?
-
-
confirmPassword(String? value, String password)
→ String?
-
-
email(String? value)
→ String?
-
-
firstName(String? value, {int lengthLimit = 5})
→ String?
-
-
lastName(String? value, {int lengthLimit = 5})
→ String?
-
-
length(String? value, {int? min, int? max, String fieldName = 'This field'})
→ String?
-
-
message(String? value, {int lengthLimit = 5})
→ String?
-
-
mobile(String value, {int length = 10})
→ String?
-
-
nameValidator(String value)
→ String?
-
-
numeric(String? value, {String fieldName = 'Value'})
→ String?
-
-
otp(String? value, {int length = 6})
→ String?
-
-
password(String? value)
→ String?
-
-
phone(String? value)
→ String?
-
-
positiveNumber(String? value, {String fieldName = 'Value'})
→ String?
-
-
postalCode(String? value)
→ String?
-
-
quantity(String? value)
→ String?
-
-
required(String? value, {String fieldName = 'This field'})
→ String?
-
-
tax(String? value)
→ String?
-
-
url(String? value)
→ String?
-
-
username(String value)
→ String?
-